<header>
    <h1 class="page-header text-center">
        {{ header_text }}

        {% if addition %}
            <small class="aa-bulletin-board-header-addition">{{ addition }}</small>
        {% endif %}
    </h1>
</header>
